==> 0.0.8.tar.gz: example/lib/common/utils.dart <==
import 'dart:io';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class Utils {
  static void log(String msg) {
    if (kDebugMode) {
      print(msg);
    }
  }

  static String getPrettyString(Object? object) {
    if (object == null) {
      return "";
    }
    return object.toString();
  }

  static Widget getText(
    String s,
    double fontSize,
    FontWeight fontWeight,
    Color color,
  ) {
    return Text(
      s,
      style: TextStyle(
        fontSize: fontSize,
        fontWeight: fontWeight,
        color: color,
      ),
    );
  }

  static Widget getTitle(
    String s,
  ) {
    return Container(
      padding: const EdgeInsets.all(16.0),
      color: Colors.red.withOpacity(0.6),
      child: Text(
        s,
        style: const TextStyle(
          fontSize: 14.0,
          fontWeight: FontWeight.w400,
          color: Colors.black,
        ),
      ),
    );
  }

  static Widget getButton(
    String text,
    double fontSize,
    Color? textColor,
    Color? backgroundColor,
    Widget? otherView,
    VoidCallback? onPressed,
  ) {
    return TextButton(
      style: TextButton.styleFrom(
        primary: textColor,
        backgroundColor: backgroundColor,
        textStyle: TextStyle(
          fontSize: fontSize,
          fontWeight: FontWeight.w400,
          overflow: TextOverflow.ellipsis,
        ),
        elevation: 0.5,
        padding: const EdgeInsets.all(16.0),
        side: const BorderSide(color: Colors.grey, width: 1.0),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(5.0)),
        ),
      ),
      onPressed: () {
        onPressed?.call();
      },
      child: SizedBox(
        height: 24.0,
        child: Row(
          children: [
            Expanded(
              child: Text(
                text,
                textAlign:
                    otherView != null ? TextAlign.start : TextAlign.center,
              ),
            ),
            if (otherView != null) const SizedBox(width: 16.0),
            if (otherView != null) otherView
          ],
        ),
      ),
    );
  }

  static Widget getTextInput(
    String labelText,
    TextInputType keyboardType,
    TextEditingController? tec,
  ) {
    return TextFormField(
      controller: tec,
      keyboardType: keyboardType,
      style: const TextStyle(
        fontWeight: FontWeight.w400,
        fontSize: 14.0,
      ),
      decoration: InputDecoration(
        labelText: labelText,
        filled: true,
        fillColor: Colors.white,
        focusedBorder: OutlineInputBorder(
          borderSide: const BorderSide(
            color: Colors.grey,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(5.0),
        ),
        enabledBorder: OutlineInputBorder(
          borderSide: const BorderSide(
            color: Colors.grey,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(5.0),
        ),
      ),
    );
  }

  static Future<String?> getDeviceId() async {
    DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();
    String? id = "";
    if (Platform.isAndroid) {
      AndroidDeviceInfo androidInfo = await deviceInfo.androidInfo;
      id = androidInfo.id;
    } else if (Platform.isIOS) {
      IosDeviceInfo iosInfo = await deviceInfo.iosInfo;
      id = iosInfo.identifierForVendor;
    }
    if (kDebugMode) {
      print("getDeviceId id $id");
    }
    return id;
  }
}

==> 0.0.12.tar.gz: example/lib/common/utils.dart <==
// import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk_example/screens/debug/debug_screen.dart';

class Utils {
  static void log(String msg) {
    if (kDebugMode) {
      print(msg);
    }
  }

  static String getPrettyString(Object? object) {
    if (object == null) {
      return "";
    }
    return object.toString();
  }

  static Widget getText(
    String s,
    double fontSize,
    FontWeight fontWeight,
    Color color,
  ) {
    return Text(
      s,
      style: TextStyle(
        fontSize: fontSize,
        fontWeight: fontWeight,
        color: color,
      ),
    );
  }

  static Widget getTitle(
    String s,
  ) {
    return Container(
      padding: const EdgeInsets.all(16.0),
      color: Colors.red.withOpacity(0.6),
      child: Text(
        s,
        style: const TextStyle(
          fontSize: 14.0,
          fontWeight: FontWeight.w400,
          color: Colors.black,
        ),
      ),
    );
  }

  static Widget getButton(
    String text,
    double fontSize,
    Color? textColor,
    Color? backgroundColor,
    Widget? otherView,
    VoidCallback? onPressed,
  ) {
    return TextButton(
      style: TextButton.styleFrom(
        foregroundColor: textColor,
        backgroundColor: backgroundColor,
        textStyle: TextStyle(
          fontSize: fontSize,
          fontWeight: FontWeight.w400,
          overflow: TextOverflow.ellipsis,
        ),
        elevation: 0.5,
        padding: const EdgeInsets.all(16.0),
        side: const BorderSide(color: Colors.grey, width: 1.0),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(5.0)),
        ),
      ),
      onPressed: () {
        onPressed?.call();
      },
      child: SizedBox(
        height: 24.0,
        child: Row(
          children: [
            Expanded(
              child: Text(
                text,
                textAlign:
                    otherView != null ? TextAlign.start : TextAlign.center,
              ),
            ),
            if (otherView != null) const SizedBox(width: 16.0),
            if (otherView != null) otherView
          ],
        ),
      ),
    );
  }

  static Widget getTextInput(
    String labelText,
    TextInputType keyboardType,
    TextEditingController? tec,
  ) {
    return TextFormField(
      controller: tec,
      keyboardType: keyboardType,
      style: const TextStyle(
        fontWeight: FontWeight.w400,
        fontSize: 14.0,
      ),
      decoration: InputDecoration(
        labelText: labelText,
        filled: true,
        fillColor: Colors.white,
        focusedBorder: OutlineInputBorder(
          borderSide: const BorderSide(
            color: Colors.grey,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(5.0),
        ),
        enabledBorder: OutlineInputBorder(
          borderSide: const BorderSide(
            color: Colors.grey,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(5.0),
        ),
      ),
    );
  }

// static Future<String?> getDeviceId() async {
//   DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();
//   String? id = "";
//   if (Platform.isAndroid) {
//     AndroidDeviceInfo androidInfo = await deviceInfo.androidInfo;
//     id = androidInfo.id;
//   } else if (Platform.isIOS) {
//     IosDeviceInfo iosInfo = await deviceInfo.iosInfo;
//     id = iosInfo.identifierForVendor;
//   }
//   if (kDebugMode) {
//     print("getDeviceId id $id");
//   }
//   return id;
// }

  static void showDebugView() {
    Get.bottomSheet(const DebugScreen());
  }

  static Widget getDebugViewIcon() {
    return IconButton(
      icon: const Icon(Icons.sos, color: Colors.red),
      onPressed: () {
        showDebugView();
      },
    );
  }
}
